@@ -1,9 +1,9 @@
 open Stdune
-module Config = Dune.Config
-module Colors = Dune.Colors
-module Clflags = Dune.Clflags
-module Package = Dune.Package
-module Profile = Dune.Profile
+module Config = Dune_engine.Config
+module Colors = Dune_rules.Colors
+module Clflags = Dune_engine.Clflags
+module Package = Dune_engine.Package
+module Profile = Dune_rules.Profile
 module Term = Cmdliner.Term
 module Manpage = Cmdliner.Manpage
 
@@ -17,7 +17,7 @@ open Let_syntax
 
 module Only_packages = struct
   type t =
-    { names : Dune.Package.Name.Set.t
+    { names : Dune_engine.Package.Name.Set.t
     ; command_line_option : string
     }
 end
@@ -33,7 +33,7 @@ type t =
   ; target_prefix : string
   ; only_packages : Only_packages.t option
   ; capture_outputs : bool
-  ; x : Dune.Context_name.t option
+  ; x : Dune_engine.Context_name.t option
   ; diff_command : string option
   ; promote : Clflags.Promote.t option
   ; force : bool
@@ -43,13 +43,13 @@ type t =
   ; store_orig_src_dir : bool
   ; (* Original arguments for the external-lib-deps hint *)
     orig_args : string list
-  ; config : Dune.Config.t
+  ; config : Dune_engine.Config.t
   ; default_target : Arg.Dep.t (* For build & runtest only *)
   ; watch : bool
   ; stats_trace_file : string option
   ; always_show_command_line : bool
   ; promote_install_files : bool
-  ; instrument_with : Dune.Lib_name.t list option
+  ; instrument_with : Dune_engine.Lib_name.t list option
   }
 
 let workspace_file t = t.workspace_file
@@ -102,7 +102,7 @@ let set_common_other ?log_file c ~targets =
       ];
   Clflags.always_show_command_line := c.always_show_command_line;
   Clflags.ignore_promoted_rules := c.ignore_promoted_rules;
-  Option.iter ~f:Dune.Stats.enable c.stats_trace_file
+  Option.iter ~f:Dune_engine.Stats.enable c.stats_trace_file
 
 let set_common ?log_file ?external_lib_deps_mode c ~targets =
   Option.iter external_lib_deps_mode ~f:(fun x ->
@@ -272,7 +272,8 @@ module Options_implied_by_dash_p = struct
       Arg.(
         value
         & opt dep
-            (Dep.alias ~dir:Stdune.Path.Local.root Dune.Alias.Name.default)
+            (Dep.alias ~dir:Stdune.Path.Local.root
+               Dune_engine.Alias.Name.default)
         & info [ "default-target" ] ~docs ~docv:"TARGET"
             ~doc:
               {|Set the default target that when none is specified to
@@ -305,7 +306,7 @@ module Options_implied_by_dash_p = struct
     ; config_file = No_config
     ; profile = Some Profile.Release
     ; default_target =
-        Arg.Dep.alias_rec ~dir:Path.Local.root Dune.Alias.Name.install
+        Arg.Dep.alias_rec ~dir:Path.Local.root Dune_engine.Alias.Name.install
     ; always_show_command_line = true
     ; promote_install_files = true
     }
@@ -385,7 +386,7 @@ module Options_implied_by_dash_p = struct
               (Printf.sprintf
                  "Select the build profile, for instance $(b,dev) or \
                   $(b,release). The default is $(b,%s)."
-                 (Profile.to_string Dune.Profile.default)))
+                 (Profile.to_string Dune_rules.Profile.default)))
     in
     match profile with
     | None -> t
@@ -424,10 +425,11 @@ let term =
     let arg =
       Arg.conv
         ( (fun s ->
-            Result.map_error (Dune.Config.Concurrency.of_string s) ~f:(fun s ->
-                `Msg s))
+            Result.map_error (Dune_engine.Config.Concurrency.of_string s)
+              ~f:(fun s -> `Msg s))
         , fun pp x ->
-            Format.pp_print_string pp (Dune.Config.Concurrency.to_string x) )
+            Format.pp_print_string pp
+              (Dune_engine.Config.Concurrency.to_string x) )
     in
     Arg.(
       value
@@ -438,10 +440,10 @@ let term =
     let arg =
       Arg.conv
         ( (fun s ->
-            Result.map_error (Dune.Sandbox_mode.of_string s) ~f:(fun s ->
+            Result.map_error (Dune_engine.Sandbox_mode.of_string s) ~f:(fun s ->
                 `Msg s))
-        , fun pp x -> Format.pp_print_string pp (Dune.Sandbox_mode.to_string x)
-        )
+        , fun pp x ->
+            Format.pp_print_string pp (Dune_engine.Sandbox_mode.to_string x) )
     in
     Arg.(
       value
@@ -457,8 +459,8 @@ let term =
                 certain sandboxing mode, so they will ignore this setting. The \
                 allowed values are: %s."
                (String.concat ~sep:", "
-                  (List.map Dune.Sandbox_mode.all
-                     ~f:Dune.Sandbox_mode.to_string))))
+                  (List.map Dune_engine.Sandbox_mode.all
+                     ~f:Dune_engine.Sandbox_mode.to_string))))
   and+ debug_dep_path =
     Arg.(
       value & flag
@@ -713,5 +715,5 @@ let config_term =
 let context_arg ~doc =
   Arg.(
     value
-    & opt Arg.context_name Dune.Context_name.default
+    & opt Arg.context_name Dune_engine.Context_name.default
     & info [ "context" ] ~docv:"CONTEXT" ~doc)
