@@ -29,7 +29,7 @@ let pp ppf ~fields sexps =
       if do_print then
         Dune_lang.Ast.add_loc sexp ~loc:Loc.none
         |> Dune_lang.Cst.concrete |> List.singleton
-        |> Format.fprintf ppf "%a@?" Dune.Format_dune_lang.pp_top_sexps)
+        |> Format.fprintf ppf "%a@?" Dune_engine.Format_dune_lang.pp_top_sexps)
 
 let term =
   let+ common = Common.term
@@ -53,14 +53,15 @@ let term =
           ( match checked with
           | In_build_dir (ctx, _) ->
             let sctx =
-              Dune.Context_name.Map.find_exn setup.scontexts ctx.name
+              Dune_engine.Context_name.Map.find_exn setup.scontexts ctx.name
             in
             [ dump sctx ~dir:(Path.as_in_build_dir_exn dir) ]
           | In_source_dir dir ->
-            Dune.Context_name.Map.values setup.scontexts
+            Dune_engine.Context_name.Map.values setup.scontexts
             |> List.map ~f:(fun sctx ->
                    let dir =
-                     Path.Build.append_source (Super_context.build_dir sctx) dir
+                     Path.Build.append_source
+                       (Super_context.context sctx).build_dir dir
                    in
                    dump sctx ~dir)
           | External _ ->
@@ -75,7 +76,7 @@ let term =
       | l ->
         List.iter l ~f:(fun (name, env) ->
             Format.printf "@[<v2>Environment for context %s:@,%a@]@."
-              (Dune.Context_name.to_string name)
+              (Dune_engine.Context_name.to_string name)
               (pp ~fields) env))
 
 let command = (term, info)
