@@ -37,7 +37,7 @@ let ( concurrency
   , !secondary
   , !force_byte_compilation )
 
-(** {2 General configuration *)
+(** {2 General configuration} *)
 
 let build_dir = "_boot"
 
@@ -53,7 +53,7 @@ let task =
   ; local_libraries = Libs.local_libraries
   }
 
-(** {2 Utility functions *)
+(** {2 Utility functions} *)
 
 open StdLabels
 open Printf
@@ -81,6 +81,33 @@ let fatal fmt =
       exit 2)
     fmt
 
+module Status_line = struct
+  let num_jobs = ref 0
+
+  let num_jobs_finished = ref 0
+
+  let displayed = ref ""
+
+  let display_status_line =
+    Unix.(isatty stdout)
+    ||
+    match Sys.getenv "INSIDE_EMACS" with
+    | (_ : string) -> true
+    | exception Not_found -> false
+
+  let update jobs =
+    if display_status_line && !num_jobs > 0 then (
+      let new_displayed =
+        sprintf "Done: %d/%d (jobs: %d)" !num_jobs_finished !num_jobs jobs
+      in
+      Printf.printf "\r%*s\r%s%!" (String.length !displayed) "" new_displayed;
+      displayed := new_displayed
+    )
+
+  let () =
+    at_exit (fun () -> Printf.printf "\r%*s\r" (String.length !displayed) "")
+end
+
 (* Return list of entries in [path] as [path/entry] *)
 let readdir path =
   Array.fold_right
@@ -366,12 +393,12 @@ end = struct
           tmp_files := Files.empty;
           Files.iter fns ~f:(fun fn -> try Sys.remove fn with _ -> ()))
 
-    let create prefix suffix =
+    let file prefix suffix =
       let fn = Filename.temp_file prefix suffix in
       tmp_files := Files.add fn !tmp_files;
       fn
 
-    let destroy fn =
+    let destroy_file fn =
       (try Sys.remove fn with _ -> ());
       tmp_files := Files.remove fn !tmp_files
   end
@@ -417,7 +444,7 @@ end = struct
       done
 
     let open_temp_file () =
-      let out = Temp.create "duneboot-" ".output" in
+      let out = Temp.file "duneboot-" ".output" in
       let fd =
         Unix.openfile out [ O_WRONLY; O_CREAT; O_TRUNC; O_SHARE_DELETE ] 0o666
       in
@@ -425,7 +452,7 @@ end = struct
 
     let read_temp fn =
       let s = read_file fn in
-      Temp.destroy fn;
+      Temp.destroy_file fn;
       s
 
     let initial_cwd = Sys.getcwd ()
@@ -500,6 +527,7 @@ end = struct
     t (fun x -> result := Some x);
     let rec loop () =
       if Hashtbl.length Process.running > 0 then (
+        Status_line.update (Hashtbl.length Process.running);
         let pid, status = Process.wait () in
         let ivar = Hashtbl.find Process.running pid in
         Hashtbl.remove Process.running pid;
@@ -526,8 +554,6 @@ module Mode = struct
 end
 
 module Config : sig
-  val ocaml_version : int * int
-
   val compiler : string
 
   val ocamldep : string
@@ -942,7 +968,7 @@ let write_args file args =
   output_string ch (String.concat ~sep:"\n" args);
   close_out ch
 
-let get_dependencies ~pp libraries =
+let get_dependencies libraries =
   let alias_files =
     List.fold_left libraries ~init:[] ~f:(fun acc (_, alias_file, _) ->
         match alias_file with
@@ -953,7 +979,7 @@ let get_dependencies ~pp libraries =
     List.map ~f:(fun (x, _, _) -> x) libraries |> List.concat
   in
   write_args "source_files" all_source_files;
-  ocamldep (pp @ mk_flags "-map" alias_files @ [ "-args"; "source_files" ])
+  ocamldep (mk_flags "-map" alias_files @ [ "-args"; "source_files" ])
   >>| fun dependencies ->
   let all_source_files =
     List.fold_left alias_files ~init:(StringSet.of_list all_source_files)
@@ -1025,7 +1051,17 @@ let sort_files dependencies ~main =
   loop (Filename.basename main);
   List.rev !res
 
-let build ~ocaml_config ~pp ~dependencies ~c_files
+let common_build_args name ~external_includes ~external_libraries =
+  List.concat
+    [ [ "-o"; Filename.concat ".." (name ^ ".exe"); "-g" ]
+    ; ( match Config.mode with
+      | Byte -> [ Config.output_complete_obj_arg ]
+      | Native -> [] )
+    ; external_includes
+    ; external_libraries
+    ]
+
+let build ~ocaml_config ~dependencies ~c_files
     { target = name, main; external_libraries; _ } =
   let ext_obj =
     try StringMap.find "ext_obj" ocaml_config with Not_found -> ".o"
@@ -1033,14 +1069,16 @@ let build ~ocaml_config ~pp ~dependencies ~c_files
   let external_libraries, external_includes =
     resolve_externals external_libraries
   in
-  let table = Hashtbl.create (List.length dependencies) in
+  let num_dependencies = List.length dependencies in
+  let table = Hashtbl.create num_dependencies in
+  Status_line.num_jobs := num_dependencies;
   let build m =
     match Hashtbl.find table m with
     | Not_started f ->
       Hashtbl.replace table m Initializing;
       Fiber.fork f >>= fun fut ->
       Hashtbl.replace table m (Started fut);
-      Fiber.Future.wait fut
+      Fiber.Future.wait fut >>| fun () -> incr Status_line.num_jobs_finished
     | Initializing -> fatal "dependency cycle!"
     | Started fut -> Fiber.Future.wait fut
     | exception Not_found -> fatal "file not found: %s" m
@@ -1053,7 +1091,6 @@ let build ~ocaml_config ~pp ~dependencies ~c_files
              Process.run ~cwd:build_dir Config.compiler
                (List.concat
                   [ [ "-c"; "-g"; "-no-alias-deps"; "-w"; "-49" ]
-                  ; pp
                   ; external_includes
                   ; [ file ]
                   ]))));
@@ -1079,18 +1116,12 @@ let build ~ocaml_config ~pp ~dependencies ~c_files
   write_args "compiled_ml_files" compiled_ml_files;
   Process.run ~cwd:build_dir Config.compiler
     (List.concat
-       [ [ "-o"; Filename.concat ".." (name ^ ".exe"); "-g" ]
-       ; ( match Config.mode with
-         | Byte -> [ Config.output_complete_obj_arg ]
-         | Native -> [] )
-       ; pp
-       ; external_includes
-       ; external_libraries
+       [ common_build_args name ~external_includes ~external_libraries
        ; obj_files
        ; [ "-args"; "compiled_ml_files" ]
        ])
 
-let build_with_single_command ~ocaml_config:_ ~pp ~dependencies ~c_files
+let build_with_single_command ~ocaml_config:_ ~dependencies ~c_files
     { target = name, main; external_libraries; _ } =
   let external_libraries, external_includes =
     resolve_externals external_libraries
@@ -1098,16 +1129,8 @@ let build_with_single_command ~ocaml_config:_ ~pp ~dependencies ~c_files
   write_args "mods_list" (sort_files dependencies ~main);
   Process.run ~cwd:build_dir Config.compiler
     (List.concat
-       [ [ "-o"
-         ; Filename.concat ".." (name ^ ".exe")
-         ; "-g"
-         ; "-no-alias-deps"
-         ; "-w"
-         ; "-49"
-         ]
-       ; pp
-       ; external_includes
-       ; external_libraries
+       [ common_build_args name ~external_includes ~external_libraries
+       ; [ "-no-alias-deps"; "-w"; "-49" ]
        ; c_files
        ; [ "-args"; "mods_list" ]
        ])
@@ -1120,62 +1143,22 @@ let rec rm_rf fn =
   | _ -> Unix.unlink fn
   | exception Unix.Unix_error (ENOENT, _, _) -> ()
 
-(** {2 ocaml-syntax-shims} *)
-
-let build_syntax_shims () =
-  if Config.ocaml_version >= (4, 08) then
-    Fiber.return []
-  else
-    let cwd = "src/ocaml-syntax-shims" in
-    Fiber.fork_and_join
-      (fun () ->
-        Process.run_and_capture ~cwd "ocaml"
-          [ "select-impl"; Sys.ocaml_version ])
-      (fun () ->
-        Process.run_and_capture ~cwd "ocaml"
-          [ "select-shims"; Sys.ocaml_version ])
-    >>= fun (impl, shims) ->
-    let build_dir = build_dir ^/ "pp" in
-    Unix.mkdir build_dir 0o777;
-    List.iter [ ("pp", impl); ("shims", shims) ] ~f:(fun (name, selector) ->
-        let dst = build_dir ^/ name ^ ".ml" in
-        if selector = "nop" then
-          close_out (open_out dst)
-        else
-          copy (cwd ^/ sprintf "%s.%s.ml" name selector) dst);
-    copy_lexer (cwd ^/ "let_trail.mll") (build_dir ^/ "let_trail.ml") ~header:""
-    >>= fun () ->
-    copy (cwd ^/ "let_trail.mli") (build_dir ^/ "let_trail.mli");
-    Process.run ~cwd:build_dir Config.compiler
-      [ "-o"
-      ; "pp.exe"
-      ; "-I"
-      ; "+compiler-libs"
-      ; "ocamlcommon" ^ Config.ocaml_archive_ext
-      ; "shims.ml"
-      ; "let_trail.mli"
-      ; "let_trail.ml"
-      ; "pp.ml"
-      ]
-    >>| fun () -> [ "-pp"; "." ^/ "pp" ^/ "pp.exe" ^ " -dump-ast" ]
-
-(** {2 Bootstrap process *)
+(** {2 Bootstrap process} *)
 let main () =
   rm_rf build_dir;
   Unix.mkdir build_dir 0o777;
   Config.ocaml_config () >>= fun ocaml_config ->
-  build_syntax_shims () >>= fun pp ->
   assemble_libraries task >>= fun libraries ->
   let c_files =
     List.map ~f:(fun (_, _, c_files) -> c_files) libraries |> List.concat
   in
-  get_dependencies ~pp libraries >>= fun dependencies ->
+  get_dependencies libraries >>= fun dependencies ->
   let build =
     if concurrency = 1 || Sys.win32 then
       build_with_single_command
     else
       build
   in
-  build ~ocaml_config ~pp ~dependencies ~c_files task
+  build ~ocaml_config ~dependencies ~c_files task
 
 let () = Fiber.run (main ())
