@@ -23,7 +23,8 @@ let local_libraries =
   ; ("otherlibs/action-plugin/src", Some "Dune_action_plugin", false, None)
   ; ("vendor/build_path_prefix_map/src", Some "Build_path_prefix_map", false,
     None)
-  ; ("src/dune", Some "Dune", true, None)
+  ; ("src/dune_engine", Some "Dune_engine", false, None)
+  ; ("src/dune_rules", Some "Dune_rules", true, None)
   ; ("vendor/cmdliner/src", None, false, None)
   ; ("otherlibs/build-info/src", Some "Build_info", false,
     Some "build_info_data")
