@@ -120,9 +120,9 @@ let set : type a b k. a Univ_map.Key.t -> a -> (b, k) parser -> (b, k) parser =
  fun key v t ctx state ->
   match ctx with
   | Values (loc, cstr, uc) ->
-    t (Values (loc, cstr, Univ_map.add uc key v)) state
+    t (Values (loc, cstr, Univ_map.set uc key v)) state
   | Fields (loc, cstr, uc) ->
-    t (Fields (loc, cstr, Univ_map.add uc key v)) state
+    t (Fields (loc, cstr, Univ_map.set uc key v)) state
 
 let set_many : type a k. Univ_map.t -> (a, k) parser -> (a, k) parser =
  fun map t ctx state ->
@@ -138,19 +138,11 @@ let loc : type k. k context -> k -> Loc.t * k =
   | Values (loc, _, _) -> (loc, state)
   | Fields (loc, _, _) -> (loc, state)
 
-let at_eos : type k. k context -> k -> bool =
+let eos : type k. k context -> k -> bool * k =
  fun ctx state ->
   match ctx with
-  | Values _ -> state = []
-  | Fields _ -> Name.Map.is_empty state.unparsed
-
-let eos ctx state = (at_eos ctx state, state)
-
-let if_eos ~then_ ~else_ ctx state =
-  if at_eos ctx state then
-    then_ ctx state
-  else
-    else_ ctx state
+  | Values _ -> (state = [], state)
+  | Fields _ -> (Name.Map.is_empty state.unparsed, state)
 
 let repeat : 'a t -> 'a list t =
   let rec loop t acc ctx l =
@@ -192,6 +184,34 @@ let parse t context sexp =
   let ctx = Values (Ast.loc sexp, None, context) in
   result ctx (t ctx [ sexp ])
 
+let fields_of_values sexps =
+  let unparsed =
+    List.fold_left sexps ~init:Name.Map.empty ~f:(fun acc sexp ->
+        match sexp with
+        | List (_, name_sexp :: values) -> (
+          match name_sexp with
+          | Atom (_, A name) ->
+            Name.Map.set acc name
+              { Fields.Unparsed.values
+              ; entry = sexp
+              ; prev = Name.Map.find acc name
+              }
+          | List (loc, _)
+          | Quoted_string (loc, _)
+          | Template { loc; _ } ->
+            User_error.raise ~loc [ Pp.text "Atom expected" ] )
+        | _ ->
+          User_error.raise ~loc:(Ast.loc sexp)
+            [ Pp.text "S-expression of the form (<name> <values>...) expected" ])
+  in
+  { Fields.unparsed; known = [] }
+
+let set_input : type k. ast list -> (unit, k) parser =
+ fun sexps context _ ->
+  match context with
+  | Values _ -> ((), sexps)
+  | Fields _ -> ((), fields_of_values sexps)
+
 let capture ctx state =
   let f t = result ctx (t ctx state) in
   (f, [])
@@ -238,17 +258,20 @@ let junk_everything : type k. (unit, k) parser =
 
 let keyword kwd =
   next (function
-    | Atom (_, s) when Atom.to_string s = kwd -> ()
+    | Atom (_, A s) when s = kwd -> ()
     | sexp ->
       User_error.raise ~loc:(Ast.loc sexp) [ Pp.textf "'%s' expected" kwd ])
 
-let match_keyword l ~fallback =
-  peek >>= function
-  | Some (Atom (_, A s)) -> (
-    match List.assoc l s with
-    | Some t -> junk >>> t
-    | None -> fallback )
-  | _ -> fallback
+let atom_matching f ~desc =
+  next (fun sexp ->
+      match
+        match sexp with
+        | Atom (_, A s) -> f s
+        | _ -> None
+      with
+      | Some x -> x
+      | None ->
+        User_error.raise ~loc:(Ast.loc sexp) [ Pp.textf "%s expected" desc ])
 
 let until_keyword kwd ~before ~after =
   let rec loop acc =
@@ -278,6 +301,13 @@ let filename =
           [ Pp.textf "'.' and '..' are not valid filenames" ]
       | fn -> fn)
 
+let relative_file =
+  plain_string (fun ~loc fn ->
+      if Filename.is_relative fn then
+        fn
+      else
+        User_error.raise ~loc [ Pp.textf "relative filename expected" ])
+
 let enter t =
   next_with_user_context (fun uc sexp ->
       match sexp with
@@ -286,19 +316,33 @@ let enter t =
         result ctx (t ctx l)
       | sexp -> User_error.raise ~loc:(Ast.loc sexp) [ Pp.text "List expected" ])
 
-let if_list ~then_ ~else_ =
-  peek_exn >>= function
-  | List _ -> then_
-  | _ -> else_
-
-let if_paren_colon_form ~then_ ~else_ =
-  peek_exn >>= function
-  | List (_, Atom (loc, A s) :: _) when String.is_prefix s ~prefix:":" ->
-    let name = String.drop s 1 in
-    enter
-      ( junk >>= fun () ->
-        then_ >>| fun f -> f (loc, name) )
-  | _ -> else_
+let ( <|> ) =
+  (* Before you read this code, close your eyes and internalise the fact that
+     this code is temporary. It is a temporary state as part of a larger work to
+     turn [Decoder.t] into a pure applicative. Once this is done, this function
+     will be implemented in a better way and with a much cleaner semantic. *)
+  let approximate_how_much_input_a_failing_branch_consumed
+      (exn : Exn_with_backtrace.t) =
+    Printexc.raw_backtrace_length exn.backtrace
+  in
+  let compare_input_consumed exn1 exn2 =
+    Int.compare
+      (approximate_how_much_input_a_failing_branch_consumed exn1)
+      (approximate_how_much_input_a_failing_branch_consumed exn2)
+  in
+  fun a b ctx state ->
+    try a ctx state
+    with exn_a -> (
+      let exn_a = Exn_with_backtrace.capture exn_a in
+      try b ctx state
+      with exn_b ->
+        let exn_b = Exn_with_backtrace.capture exn_b in
+        Exn_with_backtrace.reraise
+          ( match compare_input_consumed exn_a exn_b with
+          | Gt -> exn_a
+          | Eq
+          | Lt ->
+            exn_b ) )
 
 let fix f =
   let rec p = lazy (f r)
@@ -354,7 +398,7 @@ let located t ctx state1 =
   let x, state2 = t ctx state1 in
   ((loc_between_states ctx state1 state2, x), state2)
 
-let raw = next Fn.id
+let raw = next Fun.id
 
 let basic_loc desc f =
   next (function
@@ -386,15 +430,13 @@ let triple a b c =
       b >>= fun b ->
       c >>= fun c -> return (a, b, c) )
 
-let unit_number name suffixes =
+let unit_number_generic ~of_string ~mul name suffixes =
   let unit_number_of_string ~loc s =
     let possible_suffixes () =
       String.concat ~sep:", " (List.map ~f:fst suffixes)
     in
     let n, suffix =
-      let f c =
-        not (Char.code c >= Char.code '0' && Char.code c <= Char.code '9')
-      in
+      let f c = not (Char.is_digit c) in
       match String.findi s ~f with
       | None ->
         User_error.raise ~loc
@@ -408,26 +450,30 @@ let unit_number name suffixes =
         User_error.raise ~loc
           [ Pp.textf "invalid suffix, use one of %s" (possible_suffixes ()) ]
     in
-    Option.map ~f:(( * ) factor) (Int.of_string n)
+    Option.map ~f:(mul factor) (of_string n)
   in
   basic_loc name unit_number_of_string
 
+let unit_number = unit_number_generic ~of_string:Int.of_string ~mul:( * )
+
+let unit_number_int64 =
+  (* This can go into a separate module [stdune/int64.ml]. *)
+  let of_string s = Option.try_with (fun () -> Int64.of_string s) in
+  unit_number_generic ~of_string ~mul:Int64.mul
+
 let duration = unit_number "Duration" [ ("s", 1); ("m", 60); ("h", 60 * 60) ]
 
+(* CR-someday amokhov: Add KiB, MiB, GiB. *)
 let bytes_unit =
-  unit_number "Byte amount"
-    [ ("B", 1)
-    ; ("kB", 1000)
-    ; ("KB", 1000)
-    ; ("MB", 1000 * 1000)
-    ; ("GB", 1000 * 1000 * 1000)
+  unit_number_int64 "Byte amount"
+    [ ("B", 1L)
+    ; ("kB", 1000L)
+    ; ("KB", 1000L)
+    ; ("MB", 1000_000L)
+    ; ("GB", 1000_000_000L)
     ]
 
-let option t =
-  enter
-    (eos >>= function
-     | true -> return None
-     | false -> t >>| Option.some)
+let maybe t = t >>| Option.some <|> return None
 
 let find_cstr cstrs loc name ctx values =
   match List.assoc cstrs name with
@@ -438,15 +484,22 @@ let find_cstr cstrs loc name ctx values =
         (User_message.did_you_mean name ~candidates:(List.map cstrs ~f:fst))
       [ Pp.textf "Unknown constructor %s" name ]
 
-let sum cstrs =
+let sum ?(force_parens = false) cstrs =
   next_with_user_context (fun uc sexp ->
       match sexp with
-      | Atom (loc, A s) -> find_cstr cstrs loc s (Values (loc, Some s, uc)) []
+      | Atom (loc, A s) when not force_parens ->
+        find_cstr cstrs loc s (Values (loc, Some s, uc)) []
+      | Atom (loc, _)
       | Template { loc; _ }
-      | Quoted_string (loc, _) ->
-        User_error.raise ~loc [ Pp.text "Atom expected" ]
+      | Quoted_string (loc, _)
       | List (loc, []) ->
-        User_error.raise ~loc [ Pp.text "Non-empty list expected" ]
+        User_error.raise ~loc
+          [ Pp.textf "S-expression of the form %s expected"
+              ( if force_parens then
+                "(<atom> ...)"
+              else
+                "(<atom> ...) or <atom>" )
+          ]
       | List (loc, name :: args) -> (
         match name with
         | Quoted_string (loc, _)
@@ -559,27 +612,8 @@ let multi_field name t (Fields (_, _, uc)) (state : Fields.t) =
   (res, Fields.consume name state)
 
 let fields t (Values (loc, cstr, uc)) sexps =
-  let unparsed =
-    List.fold_left sexps ~init:Name.Map.empty ~f:(fun acc sexp ->
-        match sexp with
-        | List (_, name_sexp :: values) -> (
-          match name_sexp with
-          | Atom (_, A name) ->
-            Name.Map.set acc name
-              { Fields.Unparsed.values
-              ; entry = sexp
-              ; prev = Name.Map.find acc name
-              }
-          | List (loc, _)
-          | Quoted_string (loc, _)
-          | Template { loc; _ } ->
-            User_error.raise ~loc [ Pp.text "Atom expected" ] )
-        | _ ->
-          User_error.raise ~loc:(Ast.loc sexp)
-            [ Pp.text "S-expression of the form (<name> <values>...) expected" ])
-  in
   let ctx = Fields (loc, cstr, uc) in
-  let x = result ctx (t ctx { Fields.unparsed; known = [] }) in
+  let x = result ctx (t ctx (fields_of_values sexps)) in
   (x, [])
 
 let leftover_fields_generic t more_fields (Fields (loc, cstr, uc)) state =
