@@ -1,9 +1,7 @@
 exception E of User_message.t
 
 let prefix =
-  Pp.seq
-    (Pp.tag (Pp.verbatim "Error") ~tag:User_message.Style.Error)
-    (Pp.char ':')
+  Pp.seq (Pp.tag User_message.Style.Error (Pp.verbatim "Error")) (Pp.char ':')
 
 let make ?loc ?hints paragraphs =
   User_message.make ?loc ?hints paragraphs ~prefix
