@@ -10,7 +10,7 @@ let init =
       ( Printexc.record_backtrace false;
         Path.set_root (Path.External.cwd ());
         Path.Build.set_build_dir (Path.Build.Kind.of_string "_build");
-        Console.init Quiet;
-        Log.init () )
+        Console.Backend.(set dumb);
+        Dune_util.Log.init () )
   in
   fun () -> Lazy.force init
