@@ -1,4 +1,5 @@
-open Dune
+open Dune_engine
+open Dune_rules
 open Import
 open Dune_tests_common
 
